==> nomachine-8.4.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Exception/NodeCannotReachRequestedNode.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Exception::NodeCannotReachRequestedNode::BEGIN{package 
Exception::NodeCannotReachRequestedNode;no warnings;require base;do{
"\x62\x61\x73\x65"->import (
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x42\x61\x73\x65")};}sub 
Exception::NodeCannotReachRequestedNode::BEGIN{package 
Exception::NodeCannotReachRequestedNode;no warnings;require overload;do{
"\x6f\x76\x65\x72\x6c\x6f\x61\x64"->import ("\x22\x22",
"\x73\x74\x72\x69\x6e\x67\x69\x66\x79")};}sub 
Exception::NodeCannotReachRequestedNode::notify{package 
Exception::NodeCannotReachRequestedNode;no warnings;(my $self=shift (@_));
NXMsg::register_error ((""),
"\x65\x43\x61\x6e\x6e\x6f\x74\x43\x6f\x6e\x6e\x65\x63\x74\x54\x6f\x52\x65\x71\x75\x65\x73\x74\x65\x64\x4e\x6f\x64\x65"
,(0x07ba+ 1841-0x0c96));NXMsg::error (
"\x65\x43\x61\x6e\x6e\x6f\x74\x43\x6f\x6e\x6e\x65\x63\x74\x54\x6f\x52\x65\x71\x75\x65\x73\x74\x65\x64\x4e\x6f\x64\x65"
,"\x67\x65\x6e\x65\x72\x61\x6c");}package 
Exception::NodeCannotReachRequestedNode;no warnings;"\x3f\x3f\x3f";

==> nomachine-8.6.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/Exception/NodeCannotReachRequestedNode.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Exception::NodeCannotReachRequestedNode::BEGIN{package 
Exception::NodeCannotReachRequestedNode;no warnings;require base;do{
"\x62\x61\x73\x65"->import (
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x42\x61\x73\x65")};}sub 
Exception::NodeCannotReachRequestedNode::BEGIN{package 
Exception::NodeCannotReachRequestedNode;no warnings;require overload;do{
"\x6f\x76\x65\x72\x6c\x6f\x61\x64"->import ("\x22\x22",
"\x73\x74\x72\x69\x6e\x67\x69\x66\x79")};}sub 
Exception::NodeCannotReachRequestedNode::notify{package 
Exception::NodeCannotReachRequestedNode;no warnings;(my $self=shift (@_));
NXMsg::register_error ((""),
"\x65\x43\x61\x6e\x6e\x6f\x74\x43\x6f\x6e\x6e\x65\x63\x74\x54\x6f\x52\x65\x71\x75\x65\x73\x74\x65\x64\x4e\x6f\x64\x65"
,(0x0a44+ 5536-0x1d8f));NXMsg::error (
"\x65\x43\x61\x6e\x6e\x6f\x74\x43\x6f\x6e\x6e\x65\x63\x74\x54\x6f\x52\x65\x71\x75\x65\x73\x74\x65\x64\x4e\x6f\x64\x65"
,"\x67\x65\x6e\x65\x72\x61\x6c");}package 
Exception::NodeCannotReachRequestedNode;no warnings;"\x3f\x3f\x3f";
